@@ -2,6 +2,7 @@ package MyApp::Controller::Foo;
 use strict;
 use warnings;
 use parent 'Pickles::Controller';
+use Encode;
 
 sub init {
     my( $self, $c ) = @_;
@@ -24,6 +25,21 @@ sub post {
     $c->finished(1);
 }
 
+sub multibyte_args {
+    my( $self, $c ) = @_;
+    my $args = $c->args;
+    $c->res->content_type('text/plain');
+    $c->res->body('ok');
+    $c->finished(1);
+}
+
+sub force_status {
+    my( $self, $c ) = @_;
+    my $status = $c->req->param('status');
+    my $method = "res$status";
+    $self->$method($c);
+}
+
 1;
 
 __END__
